@@ -21,8 +21,8 @@ try:
 except:
     def free_memory():
         gc.collect()
-sys.path.append("../src")
-from TRecSys.strategies import AvgUserStrategy
+# sys.path.append("../src")
+from .strategies import AvgUserStrategy
 import pandas as pd
 
 strategy = None
@@ -46,14 +46,16 @@ class Column(BaseModel):
 
 class Schema(BaseModel):
     encoders: List[Column]
-    metric: Optional[str]='ip'
-    filters: Optional[List[Column]]=[]
-    user_encoders: Optional[List[Column]]=[]
-    id_col: Optional[str]='id'
+    metric: Optional[str] = 'ip'
+    index_factory: Optional[str] = ''
+    filters: Optional[List[Column]] = []
+    user_encoders: Optional[List[Column]] = []
+    id_col: Optional[str] = 'id'
     
     def to_dict(self):
         return {
             "metric": self.metric,
+            "index_factory": self.index_factory,
             "filters": [vars(c) for c in self.filters],
             "encoders": [vars(c) for c in self.encoders],
         }
@@ -118,10 +120,15 @@ def get_schema():
 async def api_index(data: Union[List[Dict[str, str]], str]):
     if not strategy.schema_initialized():
         return {"status": "error", "message": "Schema not initialized"}
-    if type(data)==str:
+    if type(data)==str and data.endswith(".json"):
         # read data remotely
         with open(data, 'r') as f:
             data = json.load(f)
+    elif type(data)==str and data.endswith(".csv"):
+        # read csv remotely
+        data = pd.read_csv(data)
+        affected_partitions = strategy.index_dataframe(data)
+        return {"status": "OK", "affected_partitions": affected_partitions}
     errors, affected_partitions = strategy.index(data)
     if any(errors):
         return {"status": "error", "items": errors}
